package
Version:
v0.1.3
Opens a new window with list of versions in this module.
Published: Nov 10, 2025
License: MIT
Opens a new window with license information.
Imports: 9
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GetAuthHeader returns the authorization header value
Login handles the authentication flow
Logout clears stored credentials
type AuthConfig struct {
APIKey string `json:"api_key,omitempty"`
}
type User struct {
ID string `json:"id"`
Name string `json:"name"`
Email string `json:"email"`
AvatarURL string `json:"avatarUrl,omitempty"`
}
GetCurrentUser returns the current authenticated user
Source Files
¶
Click to show internal directories.
Click to hide internal directories.